Stan Math Library: stan/math/prim/mat/err/check_cholesky_factor_corr.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_cholesky_factor_corr.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_ERR_CHECK_CHOLESKY_FACTOR_CORR_HPP
2 #define STAN_MATH_PRIM_MAT_ERR_CHECK_CHOLESKY_FACTOR_CORR_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/scal/err/check_positive.hpp>
6 #include <stan/math/prim/mat/err/check_lower_triangular.hpp>
7 #include <stan/math/prim/mat/err/check_square.hpp>
8 #include <stan/math/prim/mat/err/constraint_tolerance.hpp>
9 #include <stan/math/prim/mat/err/check_unit_vector.hpp>
10
11 namespace stan {
12
13 namespace math {
37 template <typename T_y>
38 bool
39 check_cholesky_factor_corr(
40 const char* function,
41 const char* name,
42 const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y
43 ) {
44 using Eigen::Dynamic;
45 check_square(function, name, y);
46 check_lower_triangular(function, name, y);
47 for (int i = 0; i < y.rows(); ++i)
48 check_positive(function, name, y(i, i));
49 for (int i = 0; i < y.rows(); ++i) {
50 Eigen::Matrix<T_y, Dynamic, 1>
51 y_i = y.row(i).transpose();
52 check_unit_vector(function, name, y_i);
53 }
54 return true;
55 }
56
57 }
58 }
59 #endif
check_positive.hpp
stan
Definition: log_sum_exp.hpp:8
constraint_tolerance.hpp
check_lower_triangular.hpp
stan::math::check_lower_triangular
bool check_lower_triangular(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is lower triangular.
Definition: check_lower_triangular.hpp:34
check_unit_vector.hpp
stan::math::check_positive
bool check_positive(const char *function, const char *name, const T_y &y)
Return true if y is positive.
Definition: check_positive.hpp:68
Eigen.hpp
stan::math::check_cholesky_factor_corr
bool check_cholesky_factor_corr(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is a valid Cholesky factor of a correlation matrix.
Definition: check_cholesky_factor_corr.hpp:39
stan::math::check_unit_vector
bool check_unit_vector(const char *function, const char *name, const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta)
Return true if the specified vector is unit vector.
Definition: check_unit_vector.hpp:36
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.